pub struct ExchangeRelation {
pub kinds: Option<Vec<ExchangeRelationKindsItem>>,
pub metadata: Map<String, Value>,
pub relation: Value,
}Expand description
ExchangeRelation
JSON schema
{
"type": "object",
"required": [
"relation"
],
"properties": {
"kinds": {
"description": "The list of valid exchanges an exchange relation can perform.",
"type": "array",
"items": {
"enum": [
"SCATTER_BY_FIELDS",
"SINGLE_TARGET",
"MULTI_TARGET",
"ROUND_ROBIN",
"BROADCAST"
]
},
"uniqueItems": true
},
"metadata": {
"description": "Arbitrary data created by the dialect author.",
"type": "object"
},
"relation": {
"const": "EXCHANGE"
}
},
"additionalProperties": false
}Fields
kinds: Option<Vec<ExchangeRelationKindsItem>>The list of valid exchanges an exchange relation can perform.
metadata: Map<String, Value>Arbitrary data created by the dialect author.
relation: ValueImplementations
Sourceimpl ExchangeRelation
impl ExchangeRelation
pub fn builder() -> ExchangeRelation