pub struct ReadRelation {
pub metadata: Map<String, Value>,
pub read_types: Option<Vec<ReadRelationReadTypesItem>>,
pub relation: Value,
}Expand description
ReadRelation
JSON schema
{
"type": "object",
"required": [
"relation"
],
"properties": {
"metadata": {
"description": "Arbitrary data created by the dialect author.",
"type": "object"
},
"read_types": {
"description": "The list of possible read types used by the read relation.",
"type": "array",
"items": {
"enum": [
"VIRTUAL_TABLE",
"LOCAL_FILES",
"NAMED_TABLE",
"EXTENSION_TABLE",
"ICEBERG_TABLE"
]
},
"uniqueItems": true
},
"relation": {
"const": "READ"
}
},
"additionalProperties": false
}Fields
metadata: Map<String, Value>Arbitrary data created by the dialect author.
read_types: Option<Vec<ReadRelationReadTypesItem>>The list of possible read types used by the read relation.
relation: ValueImplementations
Sourceimpl ReadRelation
impl ReadRelation
pub fn builder() -> ReadRelation