pub struct SystemFunctionMetadata {
pub name: Option<String>,
pub notation: SystemFunctionMetadataNotation,
}Expand description
System specific metadata for use in mapping Substrait to and from Common metadata fields are defined for use across dialects. Individual dialects may include additional metadata to serve their purposes.
JSON schema
{
"description": "System specific metadata for use in mapping Substrait to and from Common metadata fields are defined for use across dialects. Individual dialects may include additional metadata to serve their purposes.\n",
"type": "object",
"properties": {
"name": {
"description": "The name for this function in the system modelled by the dialect. For example, \"+\" might be the system name for \"add\".\n",
"type": "string"
},
"notation": {
"description": "The notation used to invoke this function in the system modelled by the dialect. For example, a function with system_name \"+\" could be invoked as follow: * INFIX: \"a + b\" * POSTFIX: \"a b +\", * PREFIX: \"+ a b\" * FUNCTION: \"func(a, b)\"\n",
"default": "FUNCTION",
"type": "string",
"enum": [
"INFIX",
"POSTFIX",
"PREFIX",
"FUNCTION"
]
}
},
"additionalProperties": false
}Fields
name: Option<String>The name for this function in the system modelled by the dialect. For example, “+” might be the system name for “add”.
notation: SystemFunctionMetadataNotationThe notation used to invoke this function in the system modelled by the dialect. For example, a function with system_name “+” could be invoked as follow: * INFIX: “a + b” * POSTFIX: “a b +”, * PREFIX: “+ a b” * FUNCTION: “func(a, b)”
Implementations
Sourceimpl SystemFunctionMetadata
impl SystemFunctionMetadata
pub fn builder() -> SystemFunctionMetadata